==> nvidia_modelopt-0.27.0-py3-none-manylinux_2_28_x86_64.whl: modelopt/torch/speculative/mode.py <==
# SPDX-FileCopyrightText: Copyright (c) 2024 NVIDIA CORPORATION & AFFILIATES. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
# http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

"""This module contains the mode descriptor for the quantization mode."""

from modelopt.torch.opt.config import ModeloptBaseConfig
from modelopt.torch.opt.mode import (
    ConvertEntrypoint,
    RestoreEntrypoint,
    _ModeDescriptor,
    _ModeRegistryCls,
)

from .config import EagleConfig, MedusaConfig, MTPConfig, RedrafterConfig
from .eagle.conversion import convert_to_eagle_model, restore_eagle_model
from .medusa.conversion import convert_to_medusa_model, restore_medusa_model
from .mtp.conversion import convert_to_mtp_model, restore_mtp_model
from .redrafter.conversion import convert_to_redrafter_model, restore_redrafter_model

SpeculativeDecodingModeRegistry = _ModeRegistryCls("speculative")


@SpeculativeDecodingModeRegistry.register_mode
class MedusaModeDescriptor(_ModeDescriptor):
    """Class to describe the ``"medusa"`` mode.

    The properties of this mode can be inspected via the source code.
    """

    @property
    def name(self) -> str:
        """Returns the value (str representation) of the mode."""
        return "medusa"

    @property
    def config_class(self) -> type[ModeloptBaseConfig]:
        """Specifies the config class for the mode."""
        return MedusaConfig

    @property
    def convert(self) -> ConvertEntrypoint:
        """The mode's entrypoint for converting a model."""
        return convert_to_medusa_model

    @property
    def restore(self) -> RestoreEntrypoint:
        """The mode's entrypoint for restoring a model."""
        return restore_medusa_model


@SpeculativeDecodingModeRegistry.register_mode
class EagleModeDescriptor(_ModeDescriptor):
    """Class to describe the ``"eagle"`` mode.

    The properties of this mode can be inspected via the source code.
    """

    @property
    def name(self) -> str:
        """Returns the value (str representation) of the mode."""
        return "eagle"

    @property
    def config_class(self) -> type[ModeloptBaseConfig]:
        """Specifies the config class for the mode."""
        return EagleConfig

    @property
    def convert(self) -> ConvertEntrypoint:
        """The mode's entrypoint for converting a model."""
        return convert_to_eagle_model

    @property
    def restore(self) -> RestoreEntrypoint:
        """The mode's entrypoint for restoring a model."""
        return restore_eagle_model


@SpeculativeDecodingModeRegistry.register_mode
class RedrafterModeDescriptor(_ModeDescriptor):
    """Class to describe the ``"redrafter"`` mode.

    The properties of this mode can be inspected via the source code.
    """

    @property
    def name(self) -> str:
        """Returns the value (str representation) of the mode."""
        return "redrafter"

    @property
    def config_class(self) -> type[ModeloptBaseConfig]:
        """Specifies the config class for the mode."""
        return RedrafterConfig

    @property
    def convert(self) -> ConvertEntrypoint:
        """The mode's entrypoint for converting a model."""
        return convert_to_redrafter_model

    @property
    def restore(self) -> RestoreEntrypoint:
        """The mode's entrypoint for restoring a model."""
        return restore_redrafter_model


@SpeculativeDecodingModeRegistry.register_mode
class MTPModeDescriptor(_ModeDescriptor):
    """Class to describe the ``"mtp"`` mode.

    The properties of this mode can be inspected via the source code.
    """

    @property
    def name(self) -> str:
        """Returns the value (str representation) of the mode."""
        return "mtp"

    @property
    def config_class(self) -> type[ModeloptBaseConfig]:
        """Specifies the config class for the mode."""
        return MTPConfig

    @property
    def convert(self) -> ConvertEntrypoint:
        """The mode's entrypoint for converting a model."""
        return convert_to_mtp_model

    @property
    def restore(self) -> RestoreEntrypoint:
        """The mode's entrypoint for restoring a model."""
        return restore_mtp_model

==> nvidia_modelopt-0.27.1-py3-none-manylinux_2_28_x86_64.whl: modelopt/torch/speculative/mode.py <==
# SPDX-FileCopyrightText: Copyright (c) 2024 NVIDIA CORPORATION & AFFILIATES. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
# http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

"""This module contains the mode descriptor for the quantization mode."""

from modelopt.torch.opt.config import ModeloptBaseConfig
from modelopt.torch.opt.mode import (
    ConvertEntrypoint,
    RestoreEntrypoint,
    _ModeDescriptor,
    _ModeRegistryCls,
)

from .config import EagleConfig, MedusaConfig, MTPConfig
from .eagle.conversion import convert_to_eagle_model, restore_eagle_model
from .medusa.conversion import convert_to_medusa_model, restore_medusa_model
from .mtp.conversion import convert_to_mtp_model, restore_mtp_model

SpeculativeDecodingModeRegistry = _ModeRegistryCls("speculative")


@SpeculativeDecodingModeRegistry.register_mode
class MedusaModeDescriptor(_ModeDescriptor):
    """Class to describe the ``"medusa"`` mode.

    The properties of this mode can be inspected via the source code.
    """

    @property
    def name(self) -> str:
        """Returns the value (str representation) of the mode."""
        return "medusa"

    @property
    def config_class(self) -> type[ModeloptBaseConfig]:
        """Specifies the config class for the mode."""
        return MedusaConfig

    @property
    def convert(self) -> ConvertEntrypoint:
        """The mode's entrypoint for converting a model."""
        return convert_to_medusa_model

    @property
    def restore(self) -> RestoreEntrypoint:
        """The mode's entrypoint for restoring a model."""
        return restore_medusa_model


@SpeculativeDecodingModeRegistry.register_mode
class EagleModeDescriptor(_ModeDescriptor):
    """Class to describe the ``"eagle"`` mode.

    The properties of this mode can be inspected via the source code.
    """

    @property
    def name(self) -> str:
        """Returns the value (str representation) of the mode."""
        return "eagle"

    @property
    def config_class(self) -> type[ModeloptBaseConfig]:
        """Specifies the config class for the mode."""
        return EagleConfig

    @property
    def convert(self) -> ConvertEntrypoint:
        """The mode's entrypoint for converting a model."""
        return convert_to_eagle_model

    @property
    def restore(self) -> RestoreEntrypoint:
        """The mode's entrypoint for restoring a model."""
        return restore_eagle_model


@SpeculativeDecodingModeRegistry.register_mode
class MTPModeDescriptor(_ModeDescriptor):
    """Class to describe the ``"mtp"`` mode.

    The properties of this mode can be inspected via the source code.
    """

    @property
    def name(self) -> str:
        """Returns the value (str representation) of the mode."""
        return "mtp"

    @property
    def config_class(self) -> type[ModeloptBaseConfig]:
        """Specifies the config class for the mode."""
        return MTPConfig

    @property
    def convert(self) -> ConvertEntrypoint:
        """The mode's entrypoint for converting a model."""
        return convert_to_mtp_model

    @property
    def restore(self) -> RestoreEntrypoint:
        """The mode's entrypoint for restoring a model."""
        return restore_mtp_model
